summaryrefslogtreecommitdiffstats
path: root/src/svnqt/pool.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/svnqt/pool.hpp')
-rw-r--r--src/svnqt/pool.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/svnqt/pool.hpp b/src/svnqt/pool.hpp
index accdd75..46e0a8e 100644
--- a/src/svnqt/pool.hpp
+++ b/src/svnqt/pool.hpp
@@ -46,9 +46,9 @@ namespace svn
/**
* creates a subpool new pool to an existing pool
*
* @param parent NULL -> global pool
*/
- Pool (apr_pool_t * parent = (apr_pool_t *)0);
+ Pool (apr_pool_t * tqparent = (apr_pool_t *)0);
virtual ~ Pool ();
@@ -71,7 +71,7 @@ namespace svn
*/
void renew ();
private:
- apr_pool_t * m_parent;
+ apr_pool_t * m_tqparent;
apr_pool_t * m_pool;
Pool& operator=(const Pool&);
@@ -79,7 +79,7 @@ namespace svn
Pool (const Pool &);
static bool s_initialized;
- static apr_pool_t * pool_create (apr_pool_t * parent);
+ static apr_pool_t * pool_create (apr_pool_t * tqparent);
};
}
@@ -46,9 +46,9 @@ namespace svn
* creates a subpool new pool to an existing pool
*
- * @param parent NULL -> global pool
+ * @param tqparent NULL -> global pool
*/